*********************
pip requirement files
*********************

The files found here are `requirement files
<http://pip.openplans.org/requirement-format.html>`_ that may be used with `pip
<http://pip.openplans.org/>`_.

To install the dependencies found in one of these files, simply run e.g.::

    pip install -r requirements/tests.txt
